/**
 * Copyright (C) cedarsoft GmbH.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.cedarsoft.wicket.yaml;

import com.cedarsoft.wicket.WicketConstants;
import org.apache.wicket.markup.ComponentTag;
import org.apache.wicket.markup.html.WebMarkupContainer;
import org.apache.wicket.markup.html.border.Border;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

/**
 *
 */
public class SubColumn extends Border {
  public SubColumn( @NotNull @NonNls String id, @NotNull final ColumnClasses columnClass ) {
    super( id );

    add( new WebMarkupContainer( "columnClass" ) {
      @Override
      protected void onComponentTag( ComponentTag tag ) {
        super.onComponentTag( tag );
        tag.put( WicketConstants.CLASS, columnClass.getColumnClass() );
      }
    }.add( getBodyContainer() ) );
  }

  public enum ColumnClasses {
    C_50_LEFT( "c50l" ),
    C_50_RIGHT( "c50r" ),

    C_25_LEFT( "c25l" ),
    C_25_RIGHT( "c25r" ),

    C_33_LEFT( "c33l" ),
    C_33_RIGHT( "c33r" ),

    C_38_LEFT( "c38l" ),
    C_38_RIGHT( "c38r" ),

    C_66_LEFT( "c66l" ),
    C_66_RIGHT( "c66r" ),

    C_75_LEFT( "c75l" ),
    C_75_RIGHT( "c75r" ),

    C_62_LEFT( "c62l" ),
    C_62_RIGHT( "c62r" ),;


    @NotNull
    @NonNls
    private final String columnClass;

    ColumnClasses( @NotNull @NonNls String columnClass ) {
      this.columnClass = columnClass;
    }

    @NotNull
    @NonNls
    public String getColumnClass() {
      return columnClass;
    }
  }
}
