/**
 * Copyright (C) cedarsoft GmbH.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.cedarsoft.wicket.yaml;

import com.cedarsoft.wicket.WicketConstants;
import com.cedarsoft.wicket.navigation.LinksDataView;
import com.cedarsoft.wicket.navigation.NavigationLinkProvider;
import org.apache.wicket.markup.ComponentTag;
import org.apache.wicket.markup.repeater.Item;
import org.apache.wicket.markup.repeater.data.IDataProvider;
import org.apache.wicket.model.IModel;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

/**
 *
 */
public class YamlNavigationLinksView extends LinksDataView<NavigationLinkProvider> {
  /**
   * The id for the currently active link
   */
  @NonNls
  public static final String VALUE_ID_CURRENT = "current";

  public YamlNavigationLinksView( @NotNull IDataProvider<NavigationLinkProvider> dataProvider ) {
    super( dataProvider );
  }

  @Override
  protected Item<NavigationLinkProvider> newItem( String id, int index, IModel<NavigationLinkProvider> model ) {
    return new Item<NavigationLinkProvider>( id, index, model ) {
      @Override
      protected void onComponentTag( ComponentTag tag ) {
        super.onComponentTag( tag );

        //Check whether the current link is "active"
        NavigationLinkProvider linkProvider = ( NavigationLinkProvider ) getModelObject();
        if ( linkProvider.isActive() ) {
          tag.put( WicketConstants.ID, VALUE_ID_CURRENT );
        }
      }
    };
  }
}
